/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     EOL_TOKEN = 258,
     EOF_TOKEN = 259,
     CHAR_TOKEN = 260,
     UNKNOWN_TOKEN = 261,
     INVALID_VALUE = 262,
     FLOAT_TOKEN = 263,
     INTEGER_TOKEN = 264,
     STRING_TOKEN = 265,
     COMMENT = 266,
     REQUEST_TOKEN_AREALIGHTSOURCE = 267,
     REQUEST_TOKEN_ATMOSPHERE = 268,
     REQUEST_TOKEN_ATTRIBUTE = 269,
     REQUEST_TOKEN_ATTRIBUTEBEGIN = 270,
     REQUEST_TOKEN_ATTRIBUTEEND = 271,
     REQUEST_TOKEN_BASIS = 272,
     REQUEST_TOKEN_BESSELFILTER = 273,
     REQUEST_TOKEN_BLOBBY = 274,
     REQUEST_TOKEN_BOUND = 275,
     REQUEST_TOKEN_BOXFILTER = 276,
     REQUEST_TOKEN_CATMULLROMFILTER = 277,
     REQUEST_TOKEN_CLIPPING = 278,
     REQUEST_TOKEN_COLOR = 279,
     REQUEST_TOKEN_COLORSAMPLES = 280,
     REQUEST_TOKEN_CONCATTRANSFORM = 281,
     REQUEST_TOKEN_CONE = 282,
     REQUEST_TOKEN_COORDINATESYSTEM = 283,
     REQUEST_TOKEN_COORDSYSTRANSFORM = 284,
     REQUEST_TOKEN_CROPWINDOW = 285,
     REQUEST_TOKEN_CURVES = 286,
     REQUEST_TOKEN_CYLINDER = 287,
     REQUEST_TOKEN_DECLARE = 288,
     REQUEST_TOKEN_DEFORMATION = 289,
     REQUEST_TOKEN_DEPTHOFFIELD = 290,
     REQUEST_TOKEN_DETAIL = 291,
     REQUEST_TOKEN_DETAILRANGE = 292,
     REQUEST_TOKEN_DISK = 293,
     REQUEST_TOKEN_DISKFILTER = 294,
     REQUEST_TOKEN_DISPLACEMENT = 295,
     REQUEST_TOKEN_DISPLAY = 296,
     REQUEST_TOKEN_ERRORABORT = 297,
     REQUEST_TOKEN_ERRORHANDLER = 298,
     REQUEST_TOKEN_ERRORIGNORE = 299,
     REQUEST_TOKEN_ERRORPRINT = 300,
     REQUEST_TOKEN_EXPOSURE = 301,
     REQUEST_TOKEN_EXTERIOR = 302,
     REQUEST_TOKEN_FORMAT = 303,
     REQUEST_TOKEN_FRAMEASPECTRATIO = 304,
     REQUEST_TOKEN_FRAMEBEGIN = 305,
     REQUEST_TOKEN_FRAMEEND = 306,
     REQUEST_TOKEN_GAUSSIANFILTER = 307,
     REQUEST_TOKEN_GENERALPOLYGON = 308,
     REQUEST_TOKEN_GEOMETRICAPPROXIMATION = 309,
     REQUEST_TOKEN_GEOMETRY = 310,
     REQUEST_TOKEN_HIDER = 311,
     REQUEST_TOKEN_HYPERBOLOID = 312,
     REQUEST_TOKEN_IDENTITY = 313,
     REQUEST_TOKEN_ILLUMINATE = 314,
     REQUEST_TOKEN_IMAGER = 315,
     REQUEST_TOKEN_INTERIOR = 316,
     REQUEST_TOKEN_LIGHTSOURCE = 317,
     REQUEST_TOKEN_MAKEOCCLUSION = 318,
     REQUEST_TOKEN_MAKEBUMP = 319,
     REQUEST_TOKEN_MAKECUBEFACEENVIRONMENT = 320,
     REQUEST_TOKEN_MAKELATLONGENVIRONMENT = 321,
     REQUEST_TOKEN_MAKESHADOW = 322,
     REQUEST_TOKEN_MAKETEXTURE = 323,
     REQUEST_TOKEN_MATTE = 324,
     REQUEST_TOKEN_MOTIONBEGIN = 325,
     REQUEST_TOKEN_MOTIONEND = 326,
     REQUEST_TOKEN_NUPATCH = 327,
     REQUEST_TOKEN_OBJECTBEGIN = 328,
     REQUEST_TOKEN_OBJECTEND = 329,
     REQUEST_TOKEN_OBJECTINSTANCE = 330,
     REQUEST_TOKEN_OPACITY = 331,
     REQUEST_TOKEN_OPTION = 332,
     REQUEST_TOKEN_ORIENTATION = 333,
     REQUEST_TOKEN_PARABOLOID = 334,
     REQUEST_TOKEN_PATCH = 335,
     REQUEST_TOKEN_PATCHMESH = 336,
     REQUEST_TOKEN_PERSPECTIVE = 337,
     REQUEST_TOKEN_PIXELFILTER = 338,
     REQUEST_TOKEN_PIXELSAMPLES = 339,
     REQUEST_TOKEN_PIXELVARIANCE = 340,
     REQUEST_TOKEN_POINTS = 341,
     REQUEST_TOKEN_POINTSGENERALPOLYGONS = 342,
     REQUEST_TOKEN_POINTSPOLYGONS = 343,
     REQUEST_TOKEN_POLYGON = 344,
     REQUEST_TOKEN_PROCEDURAL = 345,
     REQUEST_TOKEN_PROJECTION = 346,
     REQUEST_TOKEN_QUANTIZE = 347,
     REQUEST_TOKEN_READARCHIVE = 348,
     REQUEST_TOKEN_RELATIVEDETAIL = 349,
     REQUEST_TOKEN_REVERSEORIENTATION = 350,
     REQUEST_TOKEN_ROTATE = 351,
     REQUEST_TOKEN_SCALE = 352,
     REQUEST_TOKEN_SCREENWINDOW = 353,
     REQUEST_TOKEN_SHADINGINTERPOLATION = 354,
     REQUEST_TOKEN_SHADINGRATE = 355,
     REQUEST_TOKEN_SHUTTER = 356,
     REQUEST_TOKEN_SIDES = 357,
     REQUEST_TOKEN_SINCFILTER = 358,
     REQUEST_TOKEN_SKEW = 359,
     REQUEST_TOKEN_SOLIDBEGIN = 360,
     REQUEST_TOKEN_SOLIDEND = 361,
     REQUEST_TOKEN_SPHERE = 362,
     REQUEST_TOKEN_SUBDIVISIONMESH = 363,
     REQUEST_TOKEN_SURFACE = 364,
     REQUEST_TOKEN_TEXTURECOORDINATES = 365,
     REQUEST_TOKEN_TORUS = 366,
     REQUEST_TOKEN_TRANSFORM = 367,
     REQUEST_TOKEN_TRANSFORMBEGIN = 368,
     REQUEST_TOKEN_TRANSFORMEND = 369,
     REQUEST_TOKEN_TRANSFORMPOINTS = 370,
     REQUEST_TOKEN_TRANSLATE = 371,
     REQUEST_TOKEN_TRIANGLEFILTER = 372,
     REQUEST_TOKEN_TRIMCURVE = 373,
     REQUEST_TOKEN_VERSION = 374,
     REQUEST_TOKEN_WORLDBEGIN = 375,
     REQUEST_TOKEN_WORLDEND = 376
   };
#endif
#define EOL_TOKEN 258
#define EOF_TOKEN 259
#define CHAR_TOKEN 260
#define UNKNOWN_TOKEN 261
#define INVALID_VALUE 262
#define FLOAT_TOKEN 263
#define INTEGER_TOKEN 264
#define STRING_TOKEN 265
#define COMMENT 266
#define REQUEST_TOKEN_AREALIGHTSOURCE 267
#define REQUEST_TOKEN_ATMOSPHERE 268
#define REQUEST_TOKEN_ATTRIBUTE 269
#define REQUEST_TOKEN_ATTRIBUTEBEGIN 270
#define REQUEST_TOKEN_ATTRIBUTEEND 271
#define REQUEST_TOKEN_BASIS 272
#define REQUEST_TOKEN_BESSELFILTER 273
#define REQUEST_TOKEN_BLOBBY 274
#define REQUEST_TOKEN_BOUND 275
#define REQUEST_TOKEN_BOXFILTER 276
#define REQUEST_TOKEN_CATMULLROMFILTER 277
#define REQUEST_TOKEN_CLIPPING 278
#define REQUEST_TOKEN_COLOR 279
#define REQUEST_TOKEN_COLORSAMPLES 280
#define REQUEST_TOKEN_CONCATTRANSFORM 281
#define REQUEST_TOKEN_CONE 282
#define REQUEST_TOKEN_COORDINATESYSTEM 283
#define REQUEST_TOKEN_COORDSYSTRANSFORM 284
#define REQUEST_TOKEN_CROPWINDOW 285
#define REQUEST_TOKEN_CURVES 286
#define REQUEST_TOKEN_CYLINDER 287
#define REQUEST_TOKEN_DECLARE 288
#define REQUEST_TOKEN_DEFORMATION 289
#define REQUEST_TOKEN_DEPTHOFFIELD 290
#define REQUEST_TOKEN_DETAIL 291
#define REQUEST_TOKEN_DETAILRANGE 292
#define REQUEST_TOKEN_DISK 293
#define REQUEST_TOKEN_DISKFILTER 294
#define REQUEST_TOKEN_DISPLACEMENT 295
#define REQUEST_TOKEN_DISPLAY 296
#define REQUEST_TOKEN_ERRORABORT 297
#define REQUEST_TOKEN_ERRORHANDLER 298
#define REQUEST_TOKEN_ERRORIGNORE 299
#define REQUEST_TOKEN_ERRORPRINT 300
#define REQUEST_TOKEN_EXPOSURE 301
#define REQUEST_TOKEN_EXTERIOR 302
#define REQUEST_TOKEN_FORMAT 303
#define REQUEST_TOKEN_FRAMEASPECTRATIO 304
#define REQUEST_TOKEN_FRAMEBEGIN 305
#define REQUEST_TOKEN_FRAMEEND 306
#define REQUEST_TOKEN_GAUSSIANFILTER 307
#define REQUEST_TOKEN_GENERALPOLYGON 308
#define REQUEST_TOKEN_GEOMETRICAPPROXIMATION 309
#define REQUEST_TOKEN_GEOMETRY 310
#define REQUEST_TOKEN_HIDER 311
#define REQUEST_TOKEN_HYPERBOLOID 312
#define REQUEST_TOKEN_IDENTITY 313
#define REQUEST_TOKEN_ILLUMINATE 314
#define REQUEST_TOKEN_IMAGER 315
#define REQUEST_TOKEN_INTERIOR 316
#define REQUEST_TOKEN_LIGHTSOURCE 317
#define REQUEST_TOKEN_MAKEOCCLUSION 318
#define REQUEST_TOKEN_MAKEBUMP 319
#define REQUEST_TOKEN_MAKECUBEFACEENVIRONMENT 320
#define REQUEST_TOKEN_MAKELATLONGENVIRONMENT 321
#define REQUEST_TOKEN_MAKESHADOW 322
#define REQUEST_TOKEN_MAKETEXTURE 323
#define REQUEST_TOKEN_MATTE 324
#define REQUEST_TOKEN_MOTIONBEGIN 325
#define REQUEST_TOKEN_MOTIONEND 326
#define REQUEST_TOKEN_NUPATCH 327
#define REQUEST_TOKEN_OBJECTBEGIN 328
#define REQUEST_TOKEN_OBJECTEND 329
#define REQUEST_TOKEN_OBJECTINSTANCE 330
#define REQUEST_TOKEN_OPACITY 331
#define REQUEST_TOKEN_OPTION 332
#define REQUEST_TOKEN_ORIENTATION 333
#define REQUEST_TOKEN_PARABOLOID 334
#define REQUEST_TOKEN_PATCH 335
#define REQUEST_TOKEN_PATCHMESH 336
#define REQUEST_TOKEN_PERSPECTIVE 337
#define REQUEST_TOKEN_PIXELFILTER 338
#define REQUEST_TOKEN_PIXELSAMPLES 339
#define REQUEST_TOKEN_PIXELVARIANCE 340
#define REQUEST_TOKEN_POINTS 341
#define REQUEST_TOKEN_POINTSGENERALPOLYGONS 342
#define REQUEST_TOKEN_POINTSPOLYGONS 343
#define REQUEST_TOKEN_POLYGON 344
#define REQUEST_TOKEN_PROCEDURAL 345
#define REQUEST_TOKEN_PROJECTION 346
#define REQUEST_TOKEN_QUANTIZE 347
#define REQUEST_TOKEN_READARCHIVE 348
#define REQUEST_TOKEN_RELATIVEDETAIL 349
#define REQUEST_TOKEN_REVERSEORIENTATION 350
#define REQUEST_TOKEN_ROTATE 351
#define REQUEST_TOKEN_SCALE 352
#define REQUEST_TOKEN_SCREENWINDOW 353
#define REQUEST_TOKEN_SHADINGINTERPOLATION 354
#define REQUEST_TOKEN_SHADINGRATE 355
#define REQUEST_TOKEN_SHUTTER 356
#define REQUEST_TOKEN_SIDES 357
#define REQUEST_TOKEN_SINCFILTER 358
#define REQUEST_TOKEN_SKEW 359
#define REQUEST_TOKEN_SOLIDBEGIN 360
#define REQUEST_TOKEN_SOLIDEND 361
#define REQUEST_TOKEN_SPHERE 362
#define REQUEST_TOKEN_SUBDIVISIONMESH 363
#define REQUEST_TOKEN_SURFACE 364
#define REQUEST_TOKEN_TEXTURECOORDINATES 365
#define REQUEST_TOKEN_TORUS 366
#define REQUEST_TOKEN_TRANSFORM 367
#define REQUEST_TOKEN_TRANSFORMBEGIN 368
#define REQUEST_TOKEN_TRANSFORMEND 369
#define REQUEST_TOKEN_TRANSFORMPOINTS 370
#define REQUEST_TOKEN_TRANSLATE 371
#define REQUEST_TOKEN_TRIANGLEFILTER 372
#define REQUEST_TOKEN_TRIMCURVE 373
#define REQUEST_TOKEN_VERSION 374
#define REQUEST_TOKEN_WORLDBEGIN 375
#define REQUEST_TOKEN_WORLDEND 376




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 59 "parser.yxx"
typedef union YYSTYPE {
	int itype;
	float ftype;
	char* stype;
	char ctype;

	IntegerArray* aitype;
	FloatArray* aftype;
	StringArray* astype;
	TokenValuePair* tvtype;
	TokenValuePairs* atvtype;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 291 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif





